version 8.0
log using survival.log, replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*     File-Name:  survival.do                                           *;
*     Date:       April 19, 2005                                        *;
*     Author:     SNG                                                   *;
*     Purpose:    Using new duration dataset and Warwick 1994 data      *;
*                 to run analyses on government duration                *;
*     Data Used:  coalition.dta, warwick_dataset.dta                    *;
*     Output File:    survival.log                                      *;
*     Machine:    laptop (compaq)                                       *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;



*     ****************************************************************  *;
*                           (1) Warwick data                            *;
*       Generate single party dummy to match with King et al.'s data.   *;
*       Create censoring variable as discussed by Warwick (1994, p.29). *;
*       Note that I am using the subset of Warwick's data based on      *;
*       defining governments only by the members officially in the      *;
*       cabinet.  This is not the definition used by Warwick in his     *;
*       analyses (he includes various support parties in parliament).   *;
*       I also exclude cabinets beginning prior to 1946, and cabinets   *;
*       in Luxembourg prior to 1954, to match my data.                  *;
*     ****************************************************************  *;

use C:\datasets\warwick_dataset.dta;

sort country delec;
gen dissolution = .;
by country: gen delec_lead = delec[_n+1];
replace dissolution = 0 if delec == delec_lead;
replace dissolution = 1 if delec < delec_lead;
replace dissolution = . if delec_lead == .;
replace dissolution = 1 if endtype==1 & dissolution==.;


gen singleparty = .;
replace singleparty = 0 if npg>1 & npg<10;
replace singleparty = 1 if npg==1;

gen censored = 0;
replace censored = 1 if endtype == 1;
replace censored = 1 if endtype == 4;
replace censored = 1 if endtype == 5;
replace censored = 1 if endtype == 14;
replace censored = 1 if endtype == 15;


gen excluded = 0;
replace excluded = 1 if delec<460;
replace excluded = 1 if delec<540 & country==9;

stset dur1, failure(censored==0);

*     ****************************************************************  *;
*           replicate Druckman and Thies (AJPS 2002) results            *;
*          (first model in Table 3 of their paper) to verify that       *;
*           correct data and code is being used                         *;
*     ****************************************************************  *;

stcox majgsd postel invest rn2gsd gsdfa1r gsdd2r  gsdd3r , nohr 
robust, if ftgsd == 1 & rtallr == 1  ;



*     ****************************************************************  *;
*               All cabinets, no PEC variable                           *;
*     ****************************************************************  *;


stcox invest neff majg atts singleparty postel caretake gfa1r if 
ftg==1 & rtallr==1 & excluded==0, efron nohr cluster(country);

*     ****************************************************************  *;
*           Post-election cabinets only, no PEC variable                *;
*     ****************************************************************  *;

stcox invest neff majg atts singleparty caretake gfa1r if ftg==1 & 
postel==1 & rtallr==1 & excluded==0, efron nohr cluster(country);


*     ****************************************************************  *;
*          This is the Warwick-data pooled model in Table 7.5           *; 
*     ****************************************************************  *;

stcox invest neff majg pec atts singleparty caretake gfa1r if ftg==1 
& postel==1 & rtallr==1 & excluded==0, efron nohr cluster(country) 
schoenfeld(sc*) scaledsc(ssc*);

*     ****************************************************************  *;
*       Check proportional hazards assumption directly.                 *;
*     ****************************************************************  *;

stphtest, detail;

drop sc* ssc*;

clear;


**********************************************************************  *;
*       (2) Use new dataset, with variables from Parliamentary          *
*       Democracy Data Archive and my data.                             *;
**********************************************************************  *;


use C:\datasets\coalition.dta;


gen ciep365 = 0;
replace ciep365=1 if duration> (ciep_years*365 - 365);

gen singleparty = .;
replace singleparty = 0 if govtparties>1 & govtparties<8;
replace singleparty = 1 if govtparties==1;

stset duration, failure(ciep365==0);

*     ****************************************************************  *;
*               All cabinets, no PEC variable                           *;
*     ****************************************************************  *;

stcox investiture enpp2 majority2 incbargain singleparty range postelection caretaker, 
efron nohr cluster(country1);

*     ****************************************************************  *;
*           Post-election cabinets only, no PEC variable                *;
*     ****************************************************************  *;

stcox investiture enpp2 majority2 incbargain singleparty range caretaker
if postelection==1, efron nohr cluster(country1);

*     ****************************************************************  *;
*           This is the PDDA data pooled model used in Table 7.5        *;
*     ****************************************************************  *;

stcox investiture enpp2 majority2 pec incbargain singleparty range caretaker
if postelection==1, efron nohr cluster(country1) schoenfeld(sc*) scaledsc(ssc*);


*     ****************************************************************  *;
*       Check proportional hazards assumption directly.                 *;
*     ****************************************************************  *;

stphtest, detail;

drop sc* ssc*;

**********************************************************************  *;
*       Check the other three ideology measures                         *;
**********************************************************************  *;

stcox investiture enpp2 majority2 pec incbargain singleparty std_dev caretaker
if postelection==1, efron nohr cluster(country1);

stcox investiture enpp2 majority2 pec incbargain singleparty connected_mrg caretaker
if postelection==1, efron nohr cluster(country1);

stcox investiture enpp2 majority2 pec incbargain singleparty connected_ms caretaker
if postelection==1, efron nohr cluster(country1);




log close;
exit;
